import { h, Host } from '@stencil/core';
export class BsListGroupItem {
  constructor() {
    this.role = 'listitem';
    this.active = false;
    this.disabled = false;
    this.actionable = false;
    this.bgColor = undefined;
  }
  render() {
    return (h(Host, { class: `
                    list-group-item
                    ${this.active ? 'active' : ''}
                    ${this.disabled ? 'disabled' : ''}
                    ${this.actionable ? 'list-group-item-action' : ''}
                `, style: { "background-color": this.bgColor ? `${this.bgColor}` : null }, role: this.role, "aria-disabled": this.disabled }, h("slot", null)));
  }
  static get is() { return "bs-list-group-item"; }
  static get encapsulation() { return "shadow"; }
  static get originalStyleUrls() {
    return {
      "$": ["bs-list-group-item.scss"]
    };
  }
  static get styleUrls() {
    return {
      "$": ["bs-list-group-item.css"]
    };
  }
  static get properties() {
    return {
      "role": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "string",
          "resolved": "string",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The role lof the items for accessibility"
        },
        "attribute": "role",
        "reflect": false,
        "defaultValue": "'listitem'"
      },
      "active": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Active state view of list"
        },
        "attribute": "active",
        "reflect": false,
        "defaultValue": "false"
      },
      "disabled": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The disabled view of list"
        },
        "attribute": "disabled",
        "reflect": false,
        "defaultValue": "false"
      },
      "actionable": {
        "type": "boolean",
        "mutable": false,
        "complexType": {
          "original": "boolean",
          "resolved": "boolean",
          "references": {}
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "The item is clickable"
        },
        "attribute": "actionable",
        "reflect": false,
        "defaultValue": "false"
      },
      "bgColor": {
        "type": "string",
        "mutable": false,
        "complexType": {
          "original": "Color",
          "resolved": "\"danger\" | \"dark\" | \"info\" | \"light\" | \"muted\" | \"primary\" | \"secondary\" | \"success\" | \"warning\" | \"white\"",
          "references": {
            "Color": {
              "location": "import",
              "path": "../../shared/types"
            }
          }
        },
        "required": false,
        "optional": false,
        "docs": {
          "tags": [],
          "text": "Specify the list item's background color"
        },
        "attribute": "bg-color",
        "reflect": false
      }
    };
  }
}
//# sourceMappingURL=bs-list-group-item.js.map
